@@ -6,7 +6,7 @@
 
 #include <QUrl>
 
-#include "qquickwebenginedownloaditem.h"
+#include <private/qquickwebenginedownloadrequest_p.h>
 
 DownloadManager::DownloadManager() = default;
 
@@ -16,7 +16,7 @@ DownloadManager &DownloadManager::instance()
     return instance;
 }
 
-void DownloadManager::addDownload(std::unique_ptr<QQuickWebEngineDownloadItem> &&download)
+void DownloadManager::addDownload(std::unique_ptr<DownloadItem> &&download)
 {
     m_downloads.push_back(std::move(download));
 }
@@ -27,7 +27,7 @@ void DownloadManager::removeDownload(const int index)
     m_downloads.erase(m_downloads.begin() + index);
 }
 
-const std::vector<std::unique_ptr<QQuickWebEngineDownloadItem> > &DownloadManager::downloads()
+const std::vector<std::unique_ptr<DownloadItem>> &DownloadManager::downloads()
 {
     return m_downloads;
 }
